@@ -308,6 +308,7 @@ class JsonSchemaParser(Parser):
         use_title_as_name: bool = False,
         http_headers: Optional[Sequence[Tuple[str, str]]] = None,
         use_annotated: bool = False,
+        use_non_positive_negative_number_constrained_types: bool = False,
     ):
         super().__init__(
             source=source,
@@ -350,6 +351,7 @@ class JsonSchemaParser(Parser):
             use_title_as_name=use_title_as_name,
             http_headers=http_headers,
             use_annotated=use_annotated,
+            use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
         )
 
         self.remote_object_cache: DefaultPutDict[str, Dict[str, Any]] = DefaultPutDict()
@@ -387,7 +389,9 @@ class JsonSchemaParser(Parser):
 
     def get_data_type(self, obj: JsonSchemaObject) -> DataType:
         if obj.type is None:
-            return self.data_type_manager.get_data_type(Types.any)
+            return self.data_type_manager.get_data_type(
+                Types.any,
+            )
 
         def _get_data_type(type_: str, format__: str) -> DataType:
             data_formats: Optional[Types] = json_schema_data_formats[type_].get(
@@ -677,7 +681,9 @@ class JsonSchemaParser(Parser):
                     ],
                     is_dict=True,
                 )
-            return self.data_type_manager.get_data_type(Types.object)
+            return self.data_type_manager.get_data_type(
+                Types.object,
+            )
         elif item.enum:
             if self.should_parse_enum_as_literal(item):
                 enum_literals = item.enum
@@ -849,7 +855,9 @@ class JsonSchemaParser(Parser):
         elif obj.type:
             data_type = self.get_data_type(obj)
         else:
-            data_type = self.data_type_manager.get_data_type(Types.any)
+            data_type = self.data_type_manager.get_data_type(
+                Types.any,
+            )
         if self.force_optional_for_required_fields:
             required: bool = False
         else:
@@ -939,7 +947,9 @@ class JsonSchemaParser(Parser):
                 self.data_model_field_type(
                     name=field_name,
                     default=default,
-                    data_type=self.data_type_manager.get_data_type(Types.any),
+                    data_type=self.data_type_manager.get_data_type(
+                        Types.any,
+                    ),
                     required=True,
                     strip_default_none=self.strip_default_none,
                 )
